@@ -10,3 +10,5 @@ from .support_enumeration import support_enumeration, support_enumeration_gen
 from .lemke_howson import lemke_howson
 from .mclennan_tourky import mclennan_tourky
 from .vertex_enumeration import vertex_enumeration, vertex_enumeration_gen
+from .game_generators import *
+from .repeated_game import RepeatedGame
