@@ -7,6 +7,6 @@ from .core import mc_compute_stationary, mc_sample_path 			#-Future Deprecation-
 from .gth_solve import gth_solve
 from .random import random_markov_chain, random_stochastic_matrix, \
     random_discrete_dp
-from .approximation import tauchen
+from .approximation import tauchen, rouwenhorst
 from .ddp import DiscreteDP, backward_induction
 from .utilities import sa_indices
