@@ -1,9 +1,4 @@
 r"""
-Authors: Chase Coleman, Spencer Lyon, Daisuke Oyama, Tom Sargent,
-         John Stachurski
-
-Filename: core.py
-
 This file contains some useful objects for handling a finite-state
 discrete-time Markov chain.
 
@@ -84,7 +79,6 @@ classes*. For each :math:`S_m` and each :math:`i \in S_m`, we have
 :math:`\sum_{j \in S_{m+1}} P[i, j] = 1`, where :math:`S_d = S_0`.
 
 """
-from __future__ import division
 import numbers
 from fractions import gcd
 import numpy as np
