@@ -1,8 +1,4 @@
 r"""
-Filename: ddp.py
-
-Author: Daisuke Oyama
-
 Module for solving dynamic programs (also known as Markov decision
 processes) with finite states and actions.
 
@@ -108,7 +104,6 @@ M. L. Puterman, Markov Decision Processes: Discrete Stochastic Dynamic
 Programming, Wiley-Interscience, 2005.
 
 """
-from __future__ import division
 import warnings
 import numpy as np
 import scipy.sparse as sp
