@@ -1,6 +1,4 @@
 """
-Filename: matrix_eqn.py
-
 This file holds several functions that are used to solve matrix
 equations.  Currently has functionality to solve:
 
@@ -11,7 +9,6 @@ TODO: 1. See issue 47 on github repository, should add support for
       Sylvester equations
       2. Fix warnings from checking conditioning of matrices
 """
-from __future__ import division
 import numpy as np
 from numpy import dot
 from numpy.linalg import solve
