@@ -1,8 +1,5 @@
 """
-tests for quantecon.compute_fp module
-
-@author : Spencer Lyon
-@date : 2014-07-31
+Tests for compute_fp.py
 
 References
 ----------
@@ -12,7 +9,6 @@ https://www.math.ucdavis.edu/~hunter/book/ch3.pdf
 TODO: add multivariate case
 
 """
-from __future__ import division
 import unittest
 import numpy as np
 from nose.tools import ok_, raises
