@@ -1,7 +1,4 @@
 """
-Filename: test_graph_tools.py
-Author: Daisuke Oyama
-
 Tests for graph_tools.py
 
 """
