@@ -1,8 +1,7 @@
 """
-tests for quantecon.util
+Tests for quantecon.util
 
 """
-from __future__ import division
 from collections import Counter
 import unittest
 import numpy as np
